(release-3007.5)=
# Salt 3007.5 release notes

<!---
Do not edit this file. This is auto generated.
Edit the templates in doc/topics/releases/templates/
for a given release.
-->


<!--
Add release specific details below
-->

<!--
Do not edit the changelog below.
This is auto generated.
-->
## Changelog

### Fixed

- Zeromq RequestServer continues to serve requests after encountering an
  un-handled exception [#66519](https://github.com/saltstack/salt/issues/66519)
- * Added support for `icmpv6-type` to salt.modules.nftables [#67882](https://github.com/saltstack/salt/issues/67882)
